/*
 * Name:    d_network_dinput.c
 *
 * Purpose: MX network digital input device driver.
 *
 * Author:  William Lavender
 *
 *--------------------------------------------------------------------------
 *
 * Copyright 1999, 2001 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "mx_util.h"
#include "mx_driver.h"
#include "mx_net.h"
#include "mx_digital_input.h"
#include "d_network_dinput.h"

MX_RECORD_FUNCTION_LIST mxd_network_dinput_record_function_list = {
	mxd_network_dinput_initialize_type,
	mxd_network_dinput_create_record_structures,
	mxd_network_dinput_finish_record_initialization,
	mxd_network_dinput_delete_record,
	NULL,
	mxd_network_dinput_read_parms_from_hardware,
	mxd_network_dinput_write_parms_to_hardware,
	mxd_network_dinput_open,
	mxd_network_dinput_close
};

MX_DIGITAL_INPUT_FUNCTION_LIST mxd_network_dinput_digital_input_function_list = {
	mxd_network_dinput_read
};

MX_RECORD_FIELD_DEFAULTS mxd_network_dinput_record_field_defaults[] = {
	MX_RECORD_STANDARD_FIELDS,
	MX_DIGITAL_INPUT_STANDARD_FIELDS,
	MXD_NETWORK_DINPUT_STANDARD_FIELDS
};

long mxd_network_dinput_num_record_fields
		= sizeof( mxd_network_dinput_record_field_defaults )
			/ sizeof( mxd_network_dinput_record_field_defaults[0] );

MX_RECORD_FIELD_DEFAULTS *mxd_network_dinput_rfield_def_ptr
			= &mxd_network_dinput_record_field_defaults[0];

/* ===== */

MX_EXPORT mx_status_type
mxd_network_dinput_initialize_type( long type )
{
	return MX_SUCCESSFUL_RESULT;
}

MX_EXPORT mx_status_type
mxd_network_dinput_create_record_structures( MX_RECORD *record )
{
        const char fname[] = "mxd_network_dinput_create_record_structures()";

        MX_DIGITAL_INPUT *digital_input;
        MX_NETWORK_DINPUT *network_dinput;

        /* Allocate memory for the necessary structures. */

        digital_input = (MX_DIGITAL_INPUT *) malloc(sizeof(MX_DIGITAL_INPUT));

        if ( digital_input == (MX_DIGITAL_INPUT *) NULL ) {
                return mx_error( MXE_OUT_OF_MEMORY, fname,
                "Can't allocate memory for MX_DIGITAL_INPUT structure." );
        }

        network_dinput = (MX_NETWORK_DINPUT *)
				malloc( sizeof(MX_NETWORK_DINPUT) );

        if ( network_dinput == (MX_NETWORK_DINPUT *) NULL ) {
                return mx_error( MXE_OUT_OF_MEMORY, fname,
                "Can't allocate memory for MX_NETWORK_DINPUT structure." );
        }

        /* Now set up the necessary pointers. */

        record->record_class_struct = digital_input;
        record->record_type_struct = network_dinput;
        record->class_specific_function_list
			= &mxd_network_dinput_digital_input_function_list;

        digital_input->record = record;

        return MX_SUCCESSFUL_RESULT;
}

MX_EXPORT mx_status_type
mxd_network_dinput_finish_record_initialization( MX_RECORD *record )
{
	return MX_SUCCESSFUL_RESULT;
}

MX_EXPORT mx_status_type
mxd_network_dinput_delete_record( MX_RECORD *record )
{
        if ( record == NULL ) {
                return MX_SUCCESSFUL_RESULT;
        }
        if ( record->record_type_struct != NULL ) {
                free( record->record_type_struct );

                record->record_type_struct = NULL;
        }
        if ( record->record_class_struct != NULL ) {
                free( record->record_class_struct );

                record->record_class_struct = NULL;
        }
        return MX_SUCCESSFUL_RESULT;
}

MX_EXPORT mx_status_type
mxd_network_dinput_read_parms_from_hardware( MX_RECORD *record )
{
	return MX_SUCCESSFUL_RESULT;
}

MX_EXPORT mx_status_type
mxd_network_dinput_write_parms_to_hardware( MX_RECORD *record )
{
	return MX_SUCCESSFUL_RESULT;
}

MX_EXPORT mx_status_type
mxd_network_dinput_open( MX_RECORD *record )
{
	return MX_SUCCESSFUL_RESULT;
}

MX_EXPORT mx_status_type
mxd_network_dinput_close( MX_RECORD *record )
{
	return MX_SUCCESSFUL_RESULT;
}

MX_EXPORT mx_status_type
mxd_network_dinput_read( MX_DIGITAL_INPUT *dinput )
{
	const char fname[] = "mxd_network_dinput_read()";

	MX_NETWORK_DINPUT *network_dinput;
	char rfname[ MXU_RECORD_FIELD_NAME_LENGTH + 1 ];
	unsigned long value;
	mx_status_type status;

	network_dinput = (MX_NETWORK_DINPUT *)
				dinput->record->record_type_struct;

	if ( network_dinput == NULL ) {
		return mx_error( MXE_CORRUPT_DATA_STRUCTURE, fname,
		"MX_NETWORK_DINPUT pointer for digital input '%s' is NULL",
			dinput->record->name );
	}

	sprintf( rfname, "%s.value", network_dinput->remote_record_name );

	status = mx_get( network_dinput->server_record,
				rfname, MXFT_HEX, &value );

	dinput->value = value;

	return status;
}

