/*
 * Name:    mx_mcs.h
 *
 * Purpose: MX system header file for multichannel scalers.
 *
 * Author:  William Lavender
 *
 *-------------------------------------------------------------------------
 *
 * Copyright 1999-2002 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __MX_MCS_H__
#define __MX_MCS_H__

#include "mx_record.h"

typedef struct {
	MX_RECORD *record; /* Pointer to the MX_RECORD structure that points
			    * to this MCS.
			    */

	long maximum_num_scalers;
	long maximum_num_measurements;

	MX_RECORD *timer_record;
	MX_RECORD **scaler_record_array;

	long **data_array;

	int external_channel_advance;
	unsigned long external_prescale;

	int start;
	int stop;
	int clear;
	int busy;
	int mode;
	int parameter_type;

	double measurement_time;
	unsigned long measurement_counts;
	unsigned long current_num_scalers;
	unsigned long current_num_measurements;

	int readout_preference;

	long scaler_index;
	long measurement_index;

	double dark_current;

	double *dark_current_array;	/* Expressed in counts per second. */

	long *scaler_data;
	long *measurement_data;
	double *timer_data;

	long first_scaler_number;
} MX_MCS;

#define MXF_MCS_PREFER_READ_SCALER	1
#define MXF_MCS_PREFER_READ_MEASUREMENT	2
#define MXF_MCS_PREFER_READ_ALL		3

#define MXLV_MCS_MAXIMUM_NUM_SCALERS		1001
#define MXLV_MCS_MAXIMUM_NUM_MEASUREMENTS	1002
#define MXLV_MCS_DATA_ARRAY			1003
#define MXLV_MCS_EXTERNAL_CHANNEL_ADVANCE	1004
#define MXLV_MCS_EXTERNAL_PRESCALE		1005
#define MXLV_MCS_START				1006
#define MXLV_MCS_STOP				1007
#define MXLV_MCS_CLEAR				1008
#define MXLV_MCS_BUSY				1009
#define MXLV_MCS_MODE				1010
#define MXLV_MCS_MEASUREMENT_TIME		1011
#define MXLV_MCS_MEASUREMENT_COUNTS		1012
#define MXLV_MCS_CURRENT_NUM_SCALERS		1013
#define MXLV_MCS_CURRENT_NUM_MEASUREMENTS	1014
#define MXLV_MCS_SCALER_INDEX			1015
#define MXLV_MCS_MEASUREMENT_INDEX		1016
#define MXLV_MCS_DARK_CURRENT			1017
#define MXLV_MCS_DARK_CURRENT_ARRAY		1018
#define MXLV_MCS_SCALER_DATA			1019
#define MXLV_MCS_MEASUREMENT_DATA		1020
#define MXLV_MCS_TIMER_DATA			1021

#define MX_MCS_STANDARD_FIELDS \
  {MXLV_MCS_MAXIMUM_NUM_SCALERS, -1, "maximum_num_scalers",\
					MXFT_LONG, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, maximum_num_scalers), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {MXLV_MCS_MAXIMUM_NUM_MEASUREMENTS, -1, "maximum_num_measurements", \
					MXFT_LONG, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, maximum_num_measurements), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {MXLV_MCS_DATA_ARRAY, -1, "data_array", \
		MXFT_ULONG, NULL, 2, {MXU_VARARGS_LENGTH, MXU_VARARGS_LENGTH},\
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, data_array), \
	{sizeof(unsigned long), sizeof(unsigned long *)}, NULL, MXFF_VARARGS},\
  \
  {MXLV_MCS_EXTERNAL_CHANNEL_ADVANCE, -1, "external_channel_advance", \
					  	MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, external_channel_advance), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {MXLV_MCS_EXTERNAL_PRESCALE, -1, "external_prescale", \
	  					MXFT_ULONG, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, external_prescale), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {MXLV_MCS_START, -1, "start", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, start), \
	{0}, NULL, 0}, \
  \
  {MXLV_MCS_STOP, -1, "stop", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, stop), \
	{0}, NULL, 0}, \
  \
  {MXLV_MCS_CLEAR, -1, "clear", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, clear), \
	{0}, NULL, 0}, \
  \
  {MXLV_MCS_BUSY, -1, "busy", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, busy), \
	{0}, NULL, 0}, \
  \
  {MXLV_MCS_MODE, -1, "mode", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, mode), \
	{0}, NULL, 0}, \
  \
  {-1, -1, "parameter_type", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, parameter_type), \
	{0}, NULL, 0}, \
  \
  {MXLV_MCS_MEASUREMENT_TIME, -1, "measurement_time", MXFT_DOUBLE, NULL,0,{0},\
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, measurement_time), \
	{0}, NULL, 0}, \
  \
  {MXLV_MCS_MEASUREMENT_COUNTS, -1, "measurement_counts", \
					MXFT_ULONG, NULL,0,{0},\
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, measurement_counts), \
	{0}, NULL, 0}, \
  \
  {MXLV_MCS_CURRENT_NUM_SCALERS, -1, "current_num_scalers", \
						MXFT_LONG, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, current_num_scalers), \
	{0}, NULL, 0}, \
  \
  {MXLV_MCS_CURRENT_NUM_MEASUREMENTS, -1, "current_num_measurements", \
						MXFT_LONG, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, current_num_measurements), \
	{0}, NULL, 0}, \
  \
  {MXLV_MCS_SCALER_INDEX, -1, "scaler_index", MXFT_LONG, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, scaler_index), \
	{0}, NULL, 0}, \
  \
  {MXLV_MCS_MEASUREMENT_INDEX, -1, "measurement_index", \
					MXFT_LONG, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, measurement_index), \
	{0}, NULL, 0}, \
  \
  {MXLV_MCS_DARK_CURRENT, -1, "dark_current", MXFT_DOUBLE, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, dark_current), \
	{0}, NULL, 0}, \
  \
  {MXLV_MCS_DARK_CURRENT_ARRAY, -1, "dark_current_array", MXFT_DOUBLE, \
					NULL, 1, {MXU_VARARGS_LENGTH}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, dark_current_array), \
	{sizeof(double)}, NULL, MXFF_VARARGS}, \
  \
  {MXLV_MCS_SCALER_DATA, -1, "scaler_data", \
			MXFT_LONG, NULL, 1, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, scaler_data), \
	{sizeof(long)}, NULL, MXFF_VARARGS}, \
  \
  {MXLV_MCS_MEASUREMENT_DATA, -1, "measurement_data", \
			MXFT_LONG, NULL, 1, {MXU_VARARGS_LENGTH}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, measurement_data), \
	{sizeof(long)}, NULL, MXFF_VARARGS}, \
  \
  {MXLV_MCS_TIMER_DATA, -1, "timer_data", \
		MXFT_DOUBLE, NULL, 1, {MXU_VARARGS_LENGTH}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_MCS, timer_data), \
	{sizeof(double)}, NULL, MXFF_VARARGS}

/* Note that the 'scaler_data' field is special, since it has the MXFF_VARARGS
 * flag set, but the length of the first dimension is 0.  This means that
 * MX will dereference 'field->data_pointer' through the function
 * mx_read_void_pointer_from_memory_location(), but no memory will actually
 * be allocated for the field.
 */

typedef struct {
	mx_status_type ( *start ) ( MX_MCS *mcs );
	mx_status_type ( *stop ) ( MX_MCS *mcs );
	mx_status_type ( *clear ) ( MX_MCS *mcs );
	mx_status_type ( *busy ) ( MX_MCS *mcs );
	mx_status_type ( *read_all ) ( MX_MCS *mcs );
	mx_status_type ( *read_scaler ) ( MX_MCS *mcs );
	mx_status_type ( *read_measurement ) ( MX_MCS *mcs );
	mx_status_type ( *read_timer ) ( MX_MCS * );
	mx_status_type ( *get_parameter ) ( MX_MCS *mcs );
	mx_status_type ( *set_parameter ) ( MX_MCS *mcs );
} MX_MCS_FUNCTION_LIST;

MX_API mx_status_type mx_mcs_get_pointers( MX_RECORD *mcs_record,
	MX_MCS **mcs, MX_MCS_FUNCTION_LIST **function_list_ptr,
	const char *calling_fname );

MX_API mx_status_type mx_mcs_initialize_type(
			long record_type,
			long *num_record_fields,
			MX_RECORD_FIELD_DEFAULTS **record_field_defaults,
			long *maximum_num_scalers_varargs_cookie,
			long *maximum_num_measurements_varargs_cookie );

MX_API mx_status_type mx_mcs_finish_record_initialization(
					MX_RECORD *mcs_record );

MX_API mx_status_type mx_mcs_start( MX_RECORD *mcs_record );
MX_API mx_status_type mx_mcs_stop( MX_RECORD *mcs_record );
MX_API mx_status_type mx_mcs_clear( MX_RECORD *mcs_record );
MX_API mx_status_type mx_mcs_is_busy( MX_RECORD *mcs_record, int *busy );

MX_API mx_status_type mx_mcs_read_all( MX_RECORD *mcs_record,
					unsigned long *num_scalers,
					unsigned long *num_measurements,
					long ***mcs_data );

MX_API mx_status_type mx_mcs_read_scaler( MX_RECORD *mcs_record,
					unsigned long scaler_index,
					unsigned long *num_measurements,
					long **scaler_data );

MX_API mx_status_type mx_mcs_read_measurement( MX_RECORD *mcs_record,
					unsigned long measurement_index,
					unsigned long *num_scalers,
					long **measurement_data );

MX_API mx_status_type mx_mcs_read_timer( MX_RECORD *mcs_record,
					unsigned long *num_measurements,
					double **timer_data );

MX_API mx_status_type mx_mcs_get_mode( MX_RECORD *mcs_record, int *mode );
MX_API mx_status_type mx_mcs_set_mode( MX_RECORD *mcs_record, int mode );

MX_API mx_status_type mx_mcs_get_external_channel_advance(
					MX_RECORD *mcs_record,
					int *external_channel_advance );

MX_API mx_status_type mx_mcs_set_external_channel_advance(
					MX_RECORD *mcs_record,
					int external_channel_advance );

MX_API mx_status_type mx_mcs_get_external_prescale( MX_RECORD *mcs_record,
					unsigned long *external_prescale );

MX_API mx_status_type mx_mcs_set_external_prescale( MX_RECORD *mcs_record,
					unsigned long external_prescale );

MX_API mx_status_type mx_mcs_get_measurement_time( MX_RECORD *mcs_record,
					double *measurement_time );
MX_API mx_status_type mx_mcs_set_measurement_time( MX_RECORD *mcs_record,
					double measurement_time );

MX_API mx_status_type mx_mcs_get_measurement_counts( MX_RECORD *mcs_record,
					unsigned long *measurement_counts );
MX_API mx_status_type mx_mcs_set_measurement_counts( MX_RECORD *mcs_record,
					unsigned long measurement_counts );

MX_API mx_status_type mx_mcs_get_num_measurements( MX_RECORD *mcs_record,
					unsigned long *num_measurements );
MX_API mx_status_type mx_mcs_set_num_measurements( MX_RECORD *mcs_record,
					unsigned long num_measurements );

MX_API mx_status_type mx_mcs_get_dark_current_array( MX_RECORD *mcs_record,
					unsigned long num_scalers,
					double *dark_current_array );

MX_API mx_status_type mx_mcs_set_dark_current_array( MX_RECORD *mcs_record,
					unsigned long num_scalers,
					double *dark_current_array );

MX_API mx_status_type mx_mcs_get_dark_current( MX_RECORD *mcs_record,
					unsigned long scaler_index,
					double *dark_current );

MX_API mx_status_type mx_mcs_set_dark_current( MX_RECORD *mcs_record,
					unsigned long scaler_index,
					double dark_current );

MX_API mx_status_type mx_mcs_default_get_parameter_handler( MX_MCS *mcs );

MX_API mx_status_type mx_mcs_default_set_parameter_handler( MX_MCS *mcs );

#endif /* __MX_MCS_H__ */
